# lunRNG
### if cloudflare can have a lava lamp room i should be able to use the moon damnit!!
a pseudo random number generator* based on python's random library

![](media/tomScottJumpscare.png)

\* i cannot stress this enough do not use this for anything serious 